.. module:: view

====
View
====

Repeat
------
Menu to allow repetition of periodic unit cells. Use the 'Set unit cell'
button to set the overall unit cell to the current one.

Rotate
------
Menu to manually fine tune the viewing angle. Use 'Update' button to
set the menu to the current angle.

Colors
------
The colors menu allows numerous ways to change the color scheme and to
encode additional information into the display colors. This includes
automatic coloring by atomic numbers (default), user-specified atomic
number scheme, coloring by tags, forces, or completely manually
specified colors. In addition, several standard color scales are
available.

Settings
--------
Basic viewing settings. Also allows to constrain/unconstrain atoms and
to mark selected atoms as invisible.
